==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V2beta1ExternalMetricStatusFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V2beta1ExternalMetricStatusFluent<A extends V2beta1ExternalMetricStatusFluent<A>> extends Fluent<A>{


    public String getCurrentAverageValue();
    public A withCurrentAverageValue(String currentAverageValue);
    public Boolean hasCurrentAverageValue();
    public String getCurrentValue();
    public A withCurrentValue(String currentValue);
    public Boolean hasCurrentValue();
    public String getMetricName();
    public A withMetricName(String metricName);
    public Boolean hasMetricName();
    
/**
 * This method has been deprecated, please use method buildMetricSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getMetricSelector();
    public V1LabelSelector buildMetricSelector();
    public A withMetricSelector(V1LabelSelector metricSelector);
    public Boolean hasMetricSelector();
    public V2beta1ExternalMetricStatusFluent.MetricSelectorNested<A> withNewMetricSelector();
    public V2beta1ExternalMetricStatusFluent.MetricSelectorNested<A> withNewMetricSelectorLike(V1LabelSelector item);
    public V2beta1ExternalMetricStatusFluent.MetricSelectorNested<A> editMetricSelector();
    public V2beta1ExternalMetricStatusFluent.MetricSelectorNested<A> editOrNewMetricSelector();
    public V2beta1ExternalMetricStatusFluent.MetricSelectorNested<A> editOrNewMetricSelectorLike(V1LabelSelector item);

    public interface MetricSelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V2beta1ExternalMetricStatusFluent.MetricSelectorNested<N>>{

        
    public N and();    public N endMetricSelector();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta1ExternalMetricStatusFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V2beta1ExternalMetricStatusFluent<A extends V2beta1ExternalMetricStatusFluent<A>> extends Fluent<A>{


    public String getCurrentAverageValue();
    public A withCurrentAverageValue(String currentAverageValue);
    public Boolean hasCurrentAverageValue();
    public A withNewCurrentAverageValue(String arg1);
    public A withNewCurrentAverageValue(StringBuilder arg1);
    public A withNewCurrentAverageValue(StringBuffer arg1);
    public String getCurrentValue();
    public A withCurrentValue(String currentValue);
    public Boolean hasCurrentValue();
    public A withNewCurrentValue(String arg1);
    public A withNewCurrentValue(StringBuilder arg1);
    public A withNewCurrentValue(StringBuffer arg1);
    public String getMetricName();
    public A withMetricName(String metricName);
    public Boolean hasMetricName();
    public A withNewMetricName(String arg1);
    public A withNewMetricName(StringBuilder arg1);
    public A withNewMetricName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetricSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getMetricSelector();
    public V1LabelSelector buildMetricSelector();
    public A withMetricSelector(V1LabelSelector metricSelector);
    public Boolean hasMetricSelector();
    public V2beta1ExternalMetricStatusFluent.MetricSelectorNested<A> withNewMetricSelector();
    public V2beta1ExternalMetricStatusFluent.MetricSelectorNested<A> withNewMetricSelectorLike(V1LabelSelector item);
    public V2beta1ExternalMetricStatusFluent.MetricSelectorNested<A> editMetricSelector();
    public V2beta1ExternalMetricStatusFluent.MetricSelectorNested<A> editOrNewMetricSelector();
    public V2beta1ExternalMetricStatusFluent.MetricSelectorNested<A> editOrNewMetricSelectorLike(V1LabelSelector item);

    public interface MetricSelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V2beta1ExternalMetricStatusFluent.MetricSelectorNested<N>>{

        
    public N and();    public N endMetricSelector();
}


}
